import {ChangeDetectionStrategy, Component, EventEmitter, OnInit, Output} from '@angular/core';
import {BaseDirective} from '@app/shared/directives/base.directive';
import {LanguagesEnum} from '@app/shared/enums/languages.enum';
import {RoutesEnum} from '@app/shared/enums/routes.enum';

@Component({
  selector: 'dlcm-main-toolbar',
  templateUrl: './main-toolbar.component.html',
  styleUrls: ['./main-toolbar.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class MainToolbarComponent extends BaseDirective implements OnInit {
  @Output()
  navigateEvent: EventEmitter<string>;

  @Output()
  languageEvent: EventEmitter<string>;

  organizationalUnitPath: string = RoutesEnum.organizationalUnit;
  depositPath: string = RoutesEnum.deposit;
  accessPath: string = RoutesEnum.access;

  constructor() {
    super();
    this.navigateEvent = new EventEmitter();
    this.languageEvent = new EventEmitter();
  }

  ngOnInit() {
  }

  navigate(path: string) {
    this.navigateEvent.emit(path);
  }

  useLanguage(language: string) {
    this.languageEvent.emit(language);
  }
}
