import {ChangeDetectionStrategy, Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {DepositsModel, LanguagesModel, LicensesModel} from '@app/generated-api';
import AccessModelEnum = DepositsModel.AccessModelEnum;

@Component({
  selector: 'dlcm-create',
  templateUrl: './create.component.html',
  styleUrls: ['./create.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CreateComponent implements OnInit {
  createDepositForm: FormGroup;
  title = 'title';
  description = 'description';
  languageId = 'languageId';
  publicationDate = 'publicationDate';
  collectionBegin = 'collectionBegin';
  collectionEnd = 'collectionEnd';
  author = 'author';
  accessLevel = 'accessLevel';
  hasEmbargo = 'hasEmbargo';
  licenseId = 'licenseId';
  submissionPolicyId = 'submissionPolicyId';
  preservationPolicyId = 'preservationPolicyId';

  accessModelEnum = AccessModelEnum;

  @Input()
  languages: LanguagesModel[];

  @Input()
  licenses: LicensesModel[];

  @Output()
  submitEvent: EventEmitter<any>;

  constructor(private fb: FormBuilder) {
    this.submitEvent = new EventEmitter<any>();
  }

  ngOnInit() {
    this.createDepositForm = this.fb.group({
      title: ['', Validators.required],
      description: ['', Validators.required],
      organizationUnitId: [''],
      languageId: [''],
      publicationDate: [''],
      collectionBegin: [''],
      collectionEnd: [''],
      author: [''],
      accessLevel: [AccessModelEnum.PUBLIC],
      hasEmbargo: [false],
      licenseId: [''],
      submissionPolicyId: [''],
      preservationPolicyId: [''],
    });
  }

  onSubmit() {
    this.submitEvent.emit(this.createDepositForm.value as DepositsModel);
  }
}
