import {ChangeDetectionStrategy, Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {DepositsModel} from '@app/generated-api';
import {FieldTypeEnum} from '@app/shared/enums/field-type.enum';
import {DataTableColumnsModel} from '@app/shared/models/data-table-columns.model';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'dlcm-table',
  templateUrl: './table.component.html',
  styleUrls: ['./table.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class TableComponent implements OnInit {
  @Input()
  deposits: DepositsModel[];

  @Output()
  selectEvent: EventEmitter<string>;

  columns: DataTableColumnsModel[];

  constructor(private translate: TranslateService) {
    this.selectEvent = new EventEmitter<string>();
  }

  ngOnInit() {
    // TODO Use typeof to get interface propertie name
    this.columns = [
      {field: 'title', header: this.translate.instant('table.header.title')},
      {field: 'publicationDate', header: this.translate.instant('table.header.publicationDate'), type: FieldTypeEnum.date},
      {field: 'creation.when', header: this.translate.instant('table.header.creation.when'), type: FieldTypeEnum.datetime},
      {field: 'lastUpdate.when', header: this.translate.instant('table.header.lastUpdate.when'), type: FieldTypeEnum.datetime},
      {field: 'status', header: this.translate.instant('table.header.status')},
    ];
  }

  showDetail(deposit: DepositsModel) {
    this.selectEvent.emit(deposit.resId);
  }
}
