import {NgModule} from '@angular/core';
import {RouterModule, Routes} from '@angular/router';
import {LoginComponent} from '@app/components/login/login.component';
import {PageNotFoundComponent} from '@app/components/page-not-found/page-not-found.component';

export enum AppRoutesEnum {
  root = '',
  home = 'home',
  index = 'index',
  login = 'login',
  access = 'access',
  deposit = 'deposit',
  organizationalUnit = 'organizational-unit',
  separator = '/',
  paramId = ':id',
}

const routes: Routes = [
  {
    path: AppRoutesEnum.access,
    loadChildren: '../access/access.module#AccessModule',
  },
  {
    path: AppRoutesEnum.deposit,
    loadChildren: '../deposit/deposit.module#DepositModule',
  },
  {
    path: AppRoutesEnum.organizationalUnit,
    loadChildren: '../organizational-unit/organizational-unit.module#OrganizationalUnitModule',
  },
  {
    path: AppRoutesEnum.login,
    component: LoginComponent,
  },
  {
    path: AppRoutesEnum.root,
    redirectTo: AppRoutesEnum.access,
    pathMatch: 'full',
  },
  {
    path: AppRoutesEnum.index,
    redirectTo: '/',
    pathMatch: 'full',
  },
  {
    path: AppRoutesEnum.home,
    redirectTo: '/',
    pathMatch: 'full',
  },
  {
    path: '**',
    component: PageNotFoundComponent,
  },
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule],
})
export class AppRoutingModule {
}
