import {ChangeDetectionStrategy, Component, OnInit} from '@angular/core';
import {MatDialog} from '@angular/material';
import {ActivatedRoute} from '@angular/router';
import {OrganizationalUnitsModel} from '@app/generated-api';
import {DeleteDialog} from '@app/organizational-unit/dialogs/delete/delete.dialog';
import {DeleteDialogModel} from '@app/organizational-unit/models/delete-dialog.model';
import {GetById} from '@app/organizational-unit/organizational-unit.action';
import {OrganizationalUnitStateModel} from '@app/organizational-unit/organizational-unit.state';
import {BaseDirective} from '@app/shared/directives/base.directive';
import {RoutesEnum} from '@app/shared/enums/routes.enum';
import {StateEnum} from '@app/shared/enums/state.enum';
import {Navigate} from '@ngxs/router-plugin';
import {Select, Store} from '@ngxs/store';
import {Observable} from 'rxjs';
import {take} from 'rxjs/operators';

@Component({
  selector: 'dlcm-detail-view',
  templateUrl: './detail.view.html',
  styleUrls: ['./detail.view.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DetailView extends BaseDirective implements OnInit {
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).isLoading) isLoading$: Observable<boolean>;
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).currentOrganizationalUnit) currentOrganizationalUnit$: Observable<OrganizationalUnitsModel>;

  private resId: string;

  constructor(private store: Store,
              private route: ActivatedRoute,
              public dialog: MatDialog) {
    super();
  }

  ngOnInit() {
    this.getCurrentOrganizationalUnit();
  }

  private getCurrentOrganizationalUnit() {
    this.resId = this.route.snapshot.paramMap.get('id');
    this.getById(this.resId);
  }

  private getById(id: string) {
    this.store.dispatch(new GetById(id));
  }

  edit() {
    this.store.dispatch(new Navigate([RoutesEnum.organizationalUnitEdit, this.resId]));
  }

  delete() {
    const datas = {} as DeleteDialogModel;
    this.addToSubscription(this.currentOrganizationalUnit$.pipe(take(1)).subscribe((orgUnit: OrganizationalUnitsModel) => {
      datas.organizationalUnitName = orgUnit.name;
      datas.organizationalUnitId = orgUnit.resId;
    }));
    const dialogRef = this.dialog.open(DeleteDialog, {
      width: '250px',
      data: datas,
    });
  }
}
