import {ChangeDetectionStrategy, Component, EventEmitter, Input, OnChanges, Output, SimpleChanges, ViewEncapsulation} from '@angular/core';
import {FieldTypeEnum} from '@app/shared/enums/field-type.enum';
import {DataTableColumnsModel} from '@app/shared/models/data-table-columns.model';
import _ from 'lodash';
import * as moment from 'moment';

@Component({
  selector: 'dlcm-data-table',
  templateUrl: './data-table.component.html',
  styleUrls: ['./data-table.component.scss'],
  encapsulation: ViewEncapsulation.None,
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DataTableComponent implements OnChanges {
  @Input()
  datas: any[];

  @Input()
  columns: DataTableColumnsModel[];

  @Output()
  selectEvent: EventEmitter<any>;

  isDatasPresent: boolean;

  private readonly SEPARATOR = '.';
  private readonly FORMAT_TIME_ONLY = 'LTS';
  private readonly FORMAT_DATE_ONLY = 'L';

  constructor() {
    this.selectEvent = new EventEmitter<string>();
  }

  ngOnChanges(changes: SimpleChanges): void {
    this.isDatasPresent = this.datas.length > 0;
  }

  showDetail(row: any) {
    this.selectEvent.emit(row);
  }

  getCellData(row: any, column: DataTableColumnsModel): any {
    const data = this.getData(row, column);
    return this.applyTypeToData(data, column.type);
  }

  private getData(row: any, column: DataTableColumnsModel): any {
    const field = column.field;
    if (field.includes(this.SEPARATOR)) {
      return this.getNestedData(column, row);
    }
    return row[field];
  }

  private getNestedData(column: DataTableColumnsModel, row: any) {
    const nestedProperties: string[] = column.field.split(this.SEPARATOR);
    return row[_.last(nestedProperties)];
  }

  private applyTypeToData(data: any, type: FieldTypeEnum) {
    if (type === FieldTypeEnum.date) {
      return moment(data).format(this.FORMAT_DATE_ONLY);
    }
    if (type === FieldTypeEnum.datetime) {
      return moment(data).format(this.FORMAT_DATE_ONLY) + ' ' + moment(data).format(this.FORMAT_TIME_ONLY);
    }
    return data;
  }
}
