import {ChangeDetectionStrategy, Component, EventEmitter, OnInit, Output} from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import {distinctUntilChanged} from 'rxjs/internal/operators/distinctUntilChanged';
import {debounceTime} from 'rxjs/operators';

@Component({
  selector: 'dlcm-search',
  templateUrl: './search.component.html',
  styleUrls: ['./search.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class SearchComponent implements OnInit {
  searchForm: FormGroup;
  search = 'search';

  @Output()
  value: EventEmitter<string>;

  private debounceTime = 600;

  constructor(private fb: FormBuilder) {
    this.value = new EventEmitter<string>();
  }

  ngOnInit() {
    this.searchForm = this.fb.group({
      search: [''],
    });

    this.searchForm.get(this.search).valueChanges.pipe(
      debounceTime(this.debounceTime),
      distinctUntilChanged(),
    ).subscribe((value: string) => {
      this.value.emit(value.trim().toLocaleLowerCase());
    });
  }

}
