import {HttpClient, HttpEvent, HttpParams, HttpResponse} from '@angular/common/http';
import {Inject, Injectable, Optional} from '@angular/core';
import {BASE_PATH, CollectionModel, Configuration, DlcmService} from '@app/generated-api';
import {CustomHttpUrlEncodingCodec} from '@app/generated-api/encoder';
import {Observable} from 'rxjs';

@Injectable()
export class DlcmExtendedService extends DlcmService {

  constructor(protected httpClient: HttpClient, @Optional() @Inject(BASE_PATH) basePath: string, @Optional() configuration: Configuration) {

    super(httpClient, basePath, configuration);
  }

  public accessDipGetFilter(size?: number, page?: number, sort?: string, filters?: { [key: string]: string; }, observe?: 'body', reportProgress?: boolean): Observable<CollectionModel>;
  public accessDipGetFilter(size?: number, page?: number, sort?: string, filters?: { [key: string]: string; }, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CollectionModel>>;
  public accessDipGetFilter(size?: number, page?: number, sort?: string, filters?: { [key: string]: string; }, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CollectionModel>>;
  public accessDipGetFilter(size?: number, page?: number, sort?: string, filters?: { [key: string]: string; }, observe: any = 'body', reportProgress: boolean = false): Observable<any> {

    let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
    if (size !== undefined && size !== null) {
      queryParameters = queryParameters.set('size', <any> size);
    }
    if (page !== undefined && page !== null) {
      queryParameters = queryParameters.set('page', <any> page);
    }
    if (sort !== undefined && sort !== null) {
      queryParameters = queryParameters.set('sort', <any> sort);
    }
    if (filters !== undefined && filters !== null) {
      for (const key in filters) {
        queryParameters = queryParameters.set(key, <any> filters[key]);
      }
    }

    let headers = this.defaultHeaders;

    // to determine the Accept header
    const httpHeaderAccepts: string[] = [
      'application/hal+json',
    ];
    const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
    if (httpHeaderAcceptSelected !== undefined) {
      headers = headers.set('Accept', httpHeaderAcceptSelected);
    }

    // to determine the Content-Type header
    const consumes: string[] = [];

    return this.httpClient.get<CollectionModel>(`${this.configuration.basePath}/access/dip`,
      {
        params: queryParameters,
        withCredentials: this.configuration.withCredentials,
        headers: headers,
        observe: observe,
        reportProgress: reportProgress,
      },
    );
  }
}
