import {CommonModule} from '@angular/common';
import {NgModule} from '@angular/core';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {MaterialModule} from '@app/module/material.module';
import {DataTableComponent} from '@app/shared/components/data-table/data-table.component';
import {SearchComponent} from '@app/shared/components/search/search.component';
import {LanguageState} from '@app/shared/language.state';
import {LicenseState} from '@app/shared/license.state';
import {ClickEventService} from '@app/shared/services/clickevent.service';
import {DlcmExtendedService} from '@app/shared/services/dlcm.extended.service';
import {SharedState} from '@app/shared/shared.state';
import {FontAwesomeModule} from '@fortawesome/angular-fontawesome';
import {library} from '@fortawesome/fontawesome-svg-core';
import {fas} from '@fortawesome/free-solid-svg-icons';
import {TranslateModule} from '@ngx-translate/core';
import {NgxsModule} from '@ngxs/store';
import {PaginatorModule} from 'primeng/primeng';
import {TableModule} from 'primeng/table';
import {BaseDirective} from './directives/base.directive';

const components = [
  SearchComponent,
  DataTableComponent,
];
const directives = [
  BaseDirective,
];
const modules = [
  CommonModule,
  FormsModule,
  ReactiveFormsModule,
  MaterialModule,
  FontAwesomeModule,
  TableModule,
  PaginatorModule,
  TranslateModule,
];

@NgModule({
  declarations: [
    ...components,
    ...directives,
  ],
  imports: [
    ...modules,
    NgxsModule.forFeature([
      SharedState,
      LicenseState,
      LanguageState,
    ]),
  ],
  exports: [
    ...modules,
    ...components,
    ...directives,
  ],
  providers: [
    ClickEventService,
    DlcmExtendedService,
  ],
})
export class SharedModule {
}

// Fontawesome library
library.add(fas);
